==> taurus-2.1.0.tar.gz: taurus-2.1.0/lib/taurus/core/util/user.py <==
#!/usr/bin/env python

#############################################################################
##
## This file is part of Taurus, a Tango User Interface Library
## 
## http://www.tango-controls.org/static/taurus/latest/doc/html/index.html
##
## Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
## 
## Taurus is free software: you can redistribute it and/or modify
## it under the terms of the GNU Lesser General Public License as published by
## the Free Software Foundation, either version 3 of the License, or
## (at your option) any later version.
## 
## Taurus is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU Lesser General Public License for more details.
## 
## You should have received a copy of the GNU Lesser General Public License
## along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
##
#############################################################################

"""Finds out user inf (currently just the logged user name) for Windows and 
Posix machines. sets a USER_NAME variable containing the logged user name
defines a UNKNOWN_USER variable to which username falls back.
It also provides the getSystemUserName() function"""

__all__ = ["getSystemUserName", "USER_NAME", "UNKNOWN_USER"]

__docformat__ = "restructuredtext"

import os

#fallback. The caller of this module can check if username != UNKNOWN_USER
UNKNOWN_USER='UnknownUser' 

def getSystemUserName():
    """Finds out user inf (currently just the logged user name) for Windows and 
    Posix machines. sets a USER_NAME variable containing the logged user name
    defines a UNKNOWN_USER variable to which username falls back.
    
    :return: current user name
    :rtype: str"""
    username=''
    if os.name is 'posix': #this works for linux and macOSX
        username=os.getenv('USER')
    elif os.name is 'nt': #win NT, XP... (and Vista?)
        username=os.getenv('USERNAME')    
    if username is '': username=UNKNOWN_USER
    return username

USER_NAME=getSystemUserName()

==> taurus_3.1.0.orig.tar.gz: taurus-3.1.0/lib/taurus/core/util/user.py <==
#!/usr/bin/env python

#############################################################################
##
## This file is part of Taurus, a Tango User Interface Library
## 
## http://www.tango-controls.org/static/taurus/latest/doc/html/index.html
##
## Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
## 
## Taurus is free software: you can redistribute it and/or modify
## it under the terms of the GNU Lesser General Public License as published by
## the Free Software Foundation, either version 3 of the License, or
## (at your option) any later version.
## 
## Taurus is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU Lesser General Public License for more details.
## 
## You should have received a copy of the GNU Lesser General Public License
## along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
##
#############################################################################

"""
Finds out user inf (currently just the logged user name) for Windows and 
Posix machines. sets a USER_NAME variable containing the logged user name
defines a UNKNOWN_USER variable to which username falls back.
It also provides the getSystemUserName() function"""

__all__ = ["getSystemUserName", "USER_NAME", "UNKNOWN_USER"]

__docformat__ = "restructuredtext"

#import os
import getpass

#fallback. The caller of this module can check if username != UNKNOWN_USER
UNKNOWN_USER='UnknownUser' 

def getSystemUserName():
    """Finds out user inf (currently just the logged user name) for Windows and 
    Posix machines. sets a USER_NAME variable containing the logged user name
    defines a UNKNOWN_USER variable to which username falls back.
    
    :return: (str) current user name
    """
    try:
        return getpass.getuser()
    except:
        return UNKNOWN_USER
#    username=''
#    if os.name is 'posix': #this works for linux and macOSX
#        username=os.getenv('USER', UNKNOWN_USER)
#    elif os.name is 'nt': #win NT, XP... (and Vista?)
#        username=os.getenv('USERNAME', UNKNOWN_USER)    
#    if username == '': username=UNKNOWN_USER
#    return username

USER_NAME=getSystemUserName()
